# DateTimeLib
مكتبة بسيطة لإرجاع الوقت والتاريخ الحالي (سنة، شهر، يوم، ساعة، دقيقة، ثانية).

## التثبيت
```bash
py -m pip install DateTimeLib
```

## الاستخدام من CMD
```bash
datetimelib
# النتيجة: 2025-09-19 15:20:30
```

## الاستخدام من Python
```python
from datetime_lib import get_current_datetime

print(get_current_datetime())
# 2025-09-19 15:20:30
```
